@@ -12,8 +12,8 @@ def get_violation(**kwargs):
         key=kwargs.get('key', "abc"),
         rule=kwargs.get("rule", rule_models.Rule(pk=100)),
         violated_fields=kwargs.get("violated_fields", {'field': 'one'}),
-        content_type=kwargs.get("content_type", ContentType(pk=10)),
-        validation_object_id=kwargs.get("validation_object_id", 1),
+        trigger_content_type=kwargs.get("trigger_content_type", ContentType(pk=10)),
+        trigger_model_id=kwargs.get("trigger_model_id", 1),
         message=kwargs.get('message'),
         acceptable=kwargs.get('acceptable'),
     )
\ No newline at end of file
